#
# spec file for package jgmenu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           jgmenu
Version:        4.5.0
Release:        1.2
Summary:        Small X11 menu intended to be used with openbox and tint2
License:        GPL-2.0-only
Group:          System/X11/Utilities
URL:            https://github.com/johanmalm/jgmenu
Source:         https://github.com/johanmalm/jgmenu/archive/v%{version}.tar.gz
# Needed for typelib() - Requires.
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libmenu-cache)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.46
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)

%description
jgmenu is a simple X11 menu intended to be used with tint2 and openbox.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags} prefix=%{_prefix}

%install
make %{?_smp_mflags} prefix=%{_prefix} DESTDIR=%{buildroot} install
%suse_update_desktop_file -r %{name} Utility DesktopUtility
%python3_fix_shebang

%if 0%{?suse_version} < 1500
%post
%icon_theme_cache_post

%postun
%icon_theme_cache_postun
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%{_libexecdir}/%{name}
%{_mandir}/man?/%{name}*.?%{ext_man}

%changelog
* Mon Dec 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 4.5.0:
  * Add config option search_empty_string so that the default ''
    can be overridden. (#232)
  * Ignore entries with empty commands when de-duplicating search results. This
    makes a search for "aa" with the csv data below render two results rather
    than one. (#227)
  * jgmenu-apps: add config options --prepend-file and --append-file (#215)
  * Do not focus any item on launch/awake to increase consistency with most
    other menus (#209)
  * Make librsvg dependency optional. Also support both 2.40.x and newer.
  * Escape special characters (<, > and &) in @search widget to render
    correctly with pango markup. (#194)
  * contrib/xfce4-panel:
    + Fix xfce4-panel registration.
    + Add X-XFCE-API=2.0 to .desktop file to make the plugin work with the
    latest xfce4-panel
  * jgmenu-apps: handle name and generic-name containing commas (#192)
  * Fix widgets button-release bug by not executing widget action on button
    release if pointer has moved outside widget area since pressed (#189)
* Tue Mar 12 2024 Michael Vetter <mvetter@suse.com>
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Mon Oct 31 2022 Michael Vetter <mvetter@suse.com>
- Update to 4.4.1:
  * Chase librsvg2 API changes
    + Use rsvg_handle_render_document() to render icons instead of
    deprecated rsvg_handle_get_dimensions() and
    rsvg_handle_render_cairo(). This requres librsvg2 >= 2.46
    + jgmenu.svg: specify width and height to enable some applications
    using imlib2 >= v1.8 (such as feh and tint2) to render the
    jgmenu.svg icon correctly. This is an indirect result of the
    librsvg2 API deprecation of rsvg_handle_get_dimensions() and
    rsvg_handle_render_cairo()
  * jgmenu-apps: correctly sort desktop entries in languages other than
    English. Issue #166
  * Handle symlinked icon directories in order to support Papirus-Dark.
    Issue #122.
  * Use cache directory ${XDG_CACHE_HOME:-$HOME/.cache} rather than just
    defaulting to ~/.cache. Issue #175.
  * Fix widgets cursor-motion bug caused by background rect and text
    widgets blocking action widgets which should handle mouse-over.
    Issue #167
* Fri Sep 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.4.0:
  * Make --simple force short-lived mode (the way it was always intended to be
    an is described in documentation). Fixes issue #153.
  * jgmenu-apps:
  - Respect TryExec in .desktop files including the handling of absolute
    paths. Fixes issues #146 and #151.
  - Parse .desktop file 'Path' field and support working directory
  - Make exec[] field bigger to allow long strings (as seen in for example
    wine applications).
  - Include .desktop files in $XDG_DATA_DIRS/applications/ sub-directories
    For example, ~/.local/share/applications/wine/Programs/Games/
  * jgmenu-lx: escape C:\ in order to cope with libmenu-cache escaping the
    backslash in 'C:\' in wine applications' .desktop file Exec= field
  * gtktheme: call `jgmenu_run config` synchronously to avoid config file write
    errors
* Mon Jan  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 4.3.0:
  * Add gradient support for menu window background. Use config options
    menu_gradient_pos and color_menu_bg_to.
  * Survive locales which are not supported by X11, for example en_HK.UTF-8
  * Safely handle main event loop signals when X11 struggles to keep up
    under extreme load or on very old machines
  * obtheme: set color_title_border correctly (issue #142)
  * obtheme: parse menu.overlap.x (issue #136)
  * gtktheme: set title colours to match main menu.
  * Add persistent mode config options and --persistent command line
    option. When enabled, the menu does not exit or hide when it normally
    would, for example on selecting an item or pressing escape.
  * Add ^quit() markup. This simply exits and is designed to work with
    the persistent mode.
  * Add contib/ file jgmenu-unicode-icons.sh (PR #124)
* Wed May 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.2.1:
  * Fix apps module bug (issue #119)
* Thu May  7 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.2.0:
  * Add config options icon_norm_alpha and icon_sel_alpha.
  * Support hooks. See jgmenu(1) for full details.
  * Support startup script. Run ~/.config/jgmenu/startup on initial launch.
    This feature enables optional syncing with others settings such as GTK3.
  * gtktheme: save last theme name in ~/.cache/jgmenu/.last-gtktheme
    This supports scripts for syncing gtktheme on startup.
  * obtheme: set menu_border=0 by default to avoid inheriting unwanted menu
    border thickness if openbox theme does not contain an entry for it.
  * configure: support --libexecdir= and --libdir= (issue #109)
  * configure: use the correct xfce4panel library.
  * xfce4-panel: remove dpkg-architecture and hardcoded debian paths from
    Makefile (issue #110).
* Wed Mar  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.1.0:
  * Add i18n support for {pre,ap}pend.csv file in jgmenu-apps(1)
  * Add man page jgmenu-i18n(1)
  * Add options --no-append and --no-prepend to jgmenu-apps(1) module.
  * Whitespace-trim all comma separated fields when using the argv-buf library,
    which is used for parsing menu data and widgets. This allows CSV data to be
    indented or aligned without affecting the content.
  * Resolve tilde in --csv-file value (issue #113).
  * Add config option csv_no_duplicates to prevent applications from showing
    in multiple directories. Only supported by jgmenu-apps(1) module.
  * Respect that %% can be escaped using %%%%, when removing field codes
    (e.g. %%U and %%f) from .desktop file Exec= strings (issue #68).
    Supported by jgmenu-apps(1) and jgmenu-lx(1).
* Wed Feb  5 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.0.2:
  * sbuf.c: fix bug which could result in segfault.
  * x11-ui.c: support unusual color-depths required by applications
    such as x2go (issue #111).
* Mon Jan 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.0.1:
  * Issue #108. Show menu on correct monitor in IPC mode (position_mode=ipc)
    Before this fix, the menu would always appear on the monitor from which
    it was first launched.
  * Fix segfault bug in jgmenu-apps on OpenBSD.
  * Update lithium theme to reflect introduction of apps module
* Mon Jan 13 2020 Michael Vetter <mvetter@suse.com>
- Update to 4.0:
  * Add apps module - a replacement for pmenu and the default menu
    generator from v4.0 (hence major bump)
  * Move pmenu and lx modules to contrib/ to make maintenance and
    packaging easier.
  * jgmenu.c: hide 'last selection border' (issue #103).
  * Update man pages and usage() to prefer `jgmenu_run init` over
    `jgmenu init`
  * Add banned.h to make audits easier
  * Add scripts/pbuild to simplify building deb packages with pbuilder.
  * Add configure script in order to (a) make contrib/ packages easier
    to manange; and (b) remove dependency checking from Makefile
  * greeneye: change category 'Games' to 'Game' in order to comply with
    freedesktop.org XDG menu-spec.
  * filter.c: support case-insensitive non-ASCII search (issue #91)
* Tue Oct 22 2019 Michael Vetter <mvetter@suse.com>
- Update to 3.5:
  * Add col2 theme
  * Some minor fixes
* Mon Oct  7 2019 mvetter@suse.com
- Update to 3.4:
  * Add xfce4-panel plugin. Written-by: @Misko_2083
  * Add mate-panel plugin. This contrib/ package is still in early development.
    Written-by: @Misko_2083
  * Add the following themes: col3 and the latest bunsenlabs_lithium
  * Man pages have seen the following improvements:
  - Better html support and available at https://jgmenu.github.io/
  - A new jgmenuunicode(7) guide
  - jgmenu(1) details on IPC variables, widgets and special pango markup
    characters (thanks @johnraff)
  * Support sourcing of CSV files. Suggested-by: @johnraff
    Use the following syntax to include other files from CSV files
    . <file>
    Tilde (~) is expanded, but not environment variables.
  * In jgmenu, improve handling of tags.
  - Remove ^checkout() items without matching tags. This permits the
    default prepend.csv and append.csv files to include ^checkout()
    items which only appear if an optional package providing a sourced
    csv file is installed. Suggested-by: @johnraff
  - Die on duplicate tags
  - Survive missing tags when actioning ^checkout() and ^pipe().
    Reported-by: @johnraff
  * Improve apps module by filtering out duplicate .desktop files. For
    example if foo.desktop exists in ~/.local/share/applications/, then
    ignore foo.desktopp in /usr/share/applications/
  * Improve lx modules by ensuring tag names are unique
  * Improve ob module by
  - Escaping < and > to support pango markup
  - Fixing pipemenu inline menu bug. Reported-by: @johnraff
  * Add .clang-format and a wrapper to cope with foreach iterators
  * Minor fixes:
  - Survive unsupported locale (issue #96). If setlocale(LC_ALL, "")
    fails, use fallback 'C' locale
  - x11-ui.c: don't pull for XRandR hardware changes. Calling
    XRRGetScreenResources() pulls for hardware changes which on some
    systems freezes the screen for a few hundred milliseconds, so use
    XRRGetScreenResourcesCurrent() instead to avoid that.
    Written-by: @Roliga
  - Set arrow colour of selected item to color_sel_fg to match font
    colour (issue #99)
  - Fix border misalignment to ensure rounded corners are pixel
    perfect
  * Add config option `verbosity`. See jgmenu(1) for details.
  * Add config option `position_mode` and remove `at_pointer`
    `position_mode` can be one of pointer, ipc, fixed or center.
    See jgmenu(1) for full details.
    Backward compatibility is maintained by repecting at_pointer=1
  * Improve `jgmenu_run config` command by:
  - Creating config file if missing. Avoid failure of
    `jgmenu_run config -s <file> -k <key> -v <value>` if config file
    does not exist (by creating one).
  - Only setting key/value pair if new value is different. This
    avoids writing to jgmenurc file unnecessarily.
  - Amending missing items more intelligently by commenting out new
    key/value pairs
  * Add contrib/jgmenu-gtktheme.py. Written by @Misko-2083
    This is still a basic implementation which only sets color_menu_bg,
    color_norm_fg, color_sel_bg and color_sel_fg
    If your package maintainer has included this contrib/ package, try it out
    with: jgmenu init --apply-gtktheme
* Tue Jul 23 2019 mvetter@suse.com
- Update to 3.3:
  * In the obtheme module, add support for parsing BunsenLabs Lithium's
    bl-rc.xml to obtain the current openbox theme, thereby supporting
    jgmenu init --apply-obtheme without having to set an environment
    variable.
* Thu Jul 18 2019 mvetter@suse.com
- Update to 3.2:
  * Fix incorrect selection after clearing a filter resulting in
  * Update debian/ file and modify unit test t1201-lx.t to enable clean
    run with pbuilder
  * Add jgmenu-hide-app.sh. Run jgmenu_run hide-app foo.desktop to hide
    application foo from menu generated by lx module
  * Resolve config file csv_cmd value apps to jgmenu_run apps, so
    that user only needs to specify csv_cmd = apps to use apps module
  * Add xfce4-panel plugin. Written-by @Misko-2083
    (Not installed by default)
* Mon Jul  8 2019 mvetter@suse.com
- Update to 3.1:
  * In obtheme module, support openbox config file (rc.xml) user override
    by setting environment variable JGMENU_RCXML. For example:
    JGMENU_RCXML=$HOME/.config/openbox/bl-rc.xml jgmenu_run obtheme jgmenurc
    JGMENU_RCXML=$HOME/.config/openbox/bl-rc.xml jgmenu init --apply-obtheme
  * Minor updates to man pages
  * Fix incorrect relative path in unit test t1201-lx.t
* Wed May 22 2019 mvetter@suse.com
- Update to 3.0:
  * This release has a MAJOR bump as we have changed a few things in a
    non-backward compatible way:
    + The menu background colour is set to have no transparency by
    default (alpha changed from 85%% to 100%%)
    + tint2_look is set to 0 (false) by default. Although the alignment
    with tint2's config file can be convenient, it has caused confusion
    for a number of users.
    + The config module has been re-written in C (previously python).
    It has very similar functionality, but slighly different command
    line options. It is predominantly an internal command used by
    'init', so most users should not notice a difference.
  * Support scroll past top/bottom when using keyboard arrows (issue #90).
    When scrolling past the last item, the selection moves to the top, and
    vice versa. Suggested-by: @hhhorb
  * Add lithium-rc1 theme
  * Teach widgets module to accept keyword "auto" for fgcol.  If "auto" is
    specified instead of a "#rrggbb aa" value, the jgmenurc config file
    color_norm_fg value will be used. This is useful if you want widget
    text to take on the same colour as ordinary menu items.
  * Give menu items higher Z-order priority than widgets
  * Support movement betweeen widgets and items using keyboard. Simply
    press the <tab> button to toggle between the two. The 'greeneye' theme
    is a good place to try this out.
  * Use apps module in greeneye theme rather than lx. This enables users
    without the lx module to try it. The apps module will be a pmenu
    successor. Although it is not quite ready yet, it is good enough for
    this.
  * In the pmenu module, respect override .desktop files (issue #86). We
    now do not show .desktop files with the same filenames more than once.
    We look for .desktop files in "~/.local/share" and "$XDG_DATA_DIRS"
    before "/usr/share" and "/usr/local/share".
  * Lots of minor improvements, tweaks and fixes. See git log for full
    details.
* Mon Mar 18 2019 mvetter@suse.com
- Update to 2.2.1:
  * Fix init module bug which prevents config file from being created
* Wed Mar 13 2019 mvetter@suse.com
- Update to 2.2.:
  * Fix --hide-on-startup bug
  * Add 'obtheme' module which:
  + Reads content of in openbox's rc.xml
  + Finds and parses the associated openbox-3/themerc file
  + Sets the corresponding jgmenurc key/value pairs
  * Improvements to 'init' module:
  * add --apply-obtheme (as a wrapper for the new obtheme module)
  * use pmenu if ob does not exist for lab themes
  * add "missing" option to interactive mode
  * do not launch jgmenu on theme change
  * only backup when needed
  * Add config options color_title_{fg,bg,border} (where title refers
    to a separator with text)
  * tests/helper/Makefile: disable ASAN by default (issue #84)
* Mon Feb 25 2019 mvetter@suse.com
- Update to 2.1:
  * Hide separators when searching
  * Make ^filter() happily co-exist with type-to-search, by clearing
    any ^filer() invocation on type-to-search.  So, for example, if
    ^filter(#Network) has been applied and the user then starts
    typing, '#Network' is cleared.
  * Survive bad ^pipe() - i.e. one that returns error or no items
  * Make checkout_tag() survive invalid tag by simply reverting to
    the first menu item. This means that we now also sensibly handle
  - -checkout=foo where foo does not exist. (Reported-by: @johnraff)
  * Check that pipe-menu tags are unique before loading. Trying deal
    with duplicate tags after the node structure has been created does
    not work, because we cannot tell which ^tag() correspond to which
    ^checkout().
  * Add config option 'edge_snap_x'. Snap to left hand edge if within
    specified distance from it. Note that this option is only
    applicable in at_pointer mode.
  * (config) Simplify command 'amend' and also add --dryrun option to check for
    missing items, but without modifying jgmenurc
  * (config) Add command 'create' to create a new config file (jgmenurc) based
    on built-in default values.
  * (ob) Cope with commas in all fields (thanks @johnraff)
  * (init) Add greeneye to the built-in themes
    Try greeneye with `jgmenu init --theme=greeneye`
  * Add sharness (https://github.com/chriscool/sharness) and modify
    current unit-tests to run with it (Thanks @chriscool et al)
  * Remove redundant/superseded code, scripts, examples and tests
  * Lots of minor coding style and flawfinder fixes
  * Simplify Makefile
  * Make sure self_pipe is cleared in hide_menu() and positively
    check that menu is not hidden when opening a submenu.
* Fri Feb  1 2019 mvetter@suse.com
- Update to 2.0:
  * Support ^filter() markup, whereby ^filter(foo) in the command field
    invokes a search for the inner value 'foo'
  * filter: support multi-word search
  * Improve widgets API and fix minor issues
  * lx: output application categories as metadata
  * Add 'color_scroll_ind' and 'csv_i18n' config options
  * Add greeneye module
  * Fix KeyError bug in pmenu module (commit 3b4ba92)
  * Handle missing xsettings variables
  * i18n: support dirirectory name without '/' at end
  * ob: quote output correctly (issue #76)
  * Retire 'xdg' module (now in noncore/). Its functionality is covered
    by pmenu and lx.
  * Do not install 'ff-bookmarks' and 'places', just leave them in
    noncore/ for reference or manual install. These are not considered
    part of the core application and are too time-consuming to maintain
    across OSs.
  * Tidy up init module
* Mon Jan 28 2019 mvetter@suse.com
- Update to version 1.6:
  * Resolve '\n' characters in item names (to give new line characters)
  * Improvements to lx module
  * Improvements to openbox module
  * Fix markup bug, which sometimes results in breakage
  * Escape markup characters in "<empty>" string to show correctly
  * Set menu width correctly taking into account pango markup
* Sun Aug 26 2018 Андрей Алыпов <and.november@opensuse.org>
- update to version 1.2.1
* Sat Mar  3 2018 and.november@opensuse.org
- initial package (version 0.8.2) for openSUSE
